/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM ../../../dist/idl/nsIDOMDOMWindowResizeEventDetail.idl
 */

#ifndef __gen_nsIDOMDOMWindowResizeEventDetail_h__
#define __gen_nsIDOMDOMWindowResizeEventDetail_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIDOMDOMWindowResizeEventDetail */
#define NS_IDOMDOMWINDOWRESIZEEVENTDETAIL_IID_STR "166fa8f4-ff40-4150-ab31-272e8246e362"

#define NS_IDOMDOMWINDOWRESIZEEVENTDETAIL_IID \
  {0x166fa8f4, 0xff40, 0x4150, \
    { 0xab, 0x31, 0x27, 0x2e, 0x82, 0x46, 0xe3, 0x62 }}

class NS_NO_VTABLE nsIDOMDOMWindowResizeEventDetail : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IDOMDOMWINDOWRESIZEEVENTDETAIL_IID)

  /* readonly attribute long width; */
  NS_IMETHOD GetWidth(int32_t *aWidth) = 0;

  /* readonly attribute long height; */
  NS_IMETHOD GetHeight(int32_t *aHeight) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIDOMDOMWindowResizeEventDetail, NS_IDOMDOMWINDOWRESIZEEVENTDETAIL_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIDOMDOMWINDOWRESIZEEVENTDETAIL \
  NS_IMETHOD GetWidth(int32_t *aWidth); \
  NS_IMETHOD GetHeight(int32_t *aHeight); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIDOMDOMWINDOWRESIZEEVENTDETAIL(_to) \
  NS_IMETHOD GetWidth(int32_t *aWidth) { return _to GetWidth(aWidth); } \
  NS_IMETHOD GetHeight(int32_t *aHeight) { return _to GetHeight(aHeight); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIDOMDOMWINDOWRESIZEEVENTDETAIL(_to) \
  NS_IMETHOD GetWidth(int32_t *aWidth) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetWidth(aWidth); } \
  NS_IMETHOD GetHeight(int32_t *aHeight) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetHeight(aHeight); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsDOMDOMWindowResizeEventDetail : public nsIDOMDOMWindowResizeEventDetail
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIDOMDOMWINDOWRESIZEEVENTDETAIL

  nsDOMDOMWindowResizeEventDetail();

private:
  ~nsDOMDOMWindowResizeEventDetail();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsDOMDOMWindowResizeEventDetail, nsIDOMDOMWindowResizeEventDetail)

nsDOMDOMWindowResizeEventDetail::nsDOMDOMWindowResizeEventDetail()
{
  /* member initializers and constructor code */
}

nsDOMDOMWindowResizeEventDetail::~nsDOMDOMWindowResizeEventDetail()
{
  /* destructor code */
}

/* readonly attribute long width; */
NS_IMETHODIMP nsDOMDOMWindowResizeEventDetail::GetWidth(int32_t *aWidth)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute long height; */
NS_IMETHODIMP nsDOMDOMWindowResizeEventDetail::GetHeight(int32_t *aHeight)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIDOMDOMWindowResizeEventDetail_h__ */
